const config = require('config')

const journalName = config.get('journal.name')

const getEmailCopy = ({ emailType, titleText, expectedDate, customId }) => {
  let paragraph
  const hasLink = true
  let hasIntro = true
  let hasSignature = true
  switch (emailType) {
    case 'he-new-version-submitted':
      hasIntro = false
      hasSignature = false
      paragraph = `The authors of ${titleText} have submitted a revised version. <br/><br/>
        To review this new submission and proceed with the review process, please visit the manuscript details page.`
      break
    case 'submitted-reviewers-after-revision':
      paragraph = `The authors have submitted a new version of ${titleText}, which you reviewed for ${journalName}.<br/><br/>
        As you reviewed the previous version of this manuscript, I would be grateful if you could review this revision and submit a new report by ${expectedDate}.
        To download the updated PDF and proceed with the review process, please visit the manuscript details page.<br/><br/>
        Thank you again for reviewing for ${journalName}.`
      break
    case 'eqs-manuscript-submitted':
      paragraph = `Manuscript ID ${customId} has been submitted and a package has been sent. Please click on the link below to either approve or reject the manuscript:`
      break
    case 'coauthors-manuscript-submitted':
      paragraph = `${titleText}.<br/><br/>
        To confirm the submission and view the status of the manuscript, please verify your details by clicking the link below.<br/><br/>
        Thank you for submitting your work to ${journalName}.
      `
      break
    case 'submitting-author-manuscript-submitted':
      paragraph = `Congratulations, ${titleText} has been successfully submitted to ${journalName}.<br/><br/>
        We will confirm this submission with all authors of the manuscript, but you will be the primary recipient of communications from the journal.
        As submitting author, you will be responsible for responding to editorial queries and making updates to the manuscript. <br/><br/>
        In order to view the status of the manuscript, please visit the manuscript details page.<br/><br/>
        Thank you for submitting your work to ${journalName}.
      `
      break
    default:
      throw new Error(`The ${emailType} email type is not defined.`)
  }

  return { paragraph, hasLink, hasIntro, hasSignature }
}

module.exports = {
  getEmailCopy,
}
